pub struct ProgramHypothesisSetV1 {
pub schema_version: String,
pub discovery_program_id: DiscoveryProgramId,
pub hypothesis_refs: Vec<String>,
pub horizon_only: bool,
}Fields
schema_version: Stringdiscovery_program_id: DiscoveryProgramIdhypothesis_refs: Vec<String>horizon_only: boolTrait Implementations
Sourceimpl Clone for ProgramHypothesisSetV1
impl Clone for ProgramHypothesisSetV1
Sourcefn clone(&self) -> ProgramHypothesisSetV1
fn clone(&self) -> ProgramHypothesisSetV1
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ProgramHypothesisSetV1
impl Debug for ProgramHypothesisSetV1
Sourceimpl<'de> Deserialize<'de> for ProgramHypothesisSetV1
impl<'de> Deserialize<'de> for ProgramHypothesisSetV1
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for ProgramHypothesisSetV1
Sourceimpl JsonSchema for ProgramHypothesisSetV1
impl JsonSchema for ProgramHypothesisSetV1
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for ProgramHypothesisSetV1
impl PartialEq for ProgramHypothesisSetV1
Sourcefn eq(&self, other: &ProgramHypothesisSetV1) -> bool
fn eq(&self, other: &ProgramHypothesisSetV1) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for ProgramHypothesisSetV1
impl Serialize for ProgramHypothesisSetV1
impl StructuralPartialEq for ProgramHypothesisSetV1